@@ -49,9 +49,9 @@ void TextEdit::keyPressEvent(QKeyEvent* keyEvent)
 {
     if (keyEvent->modifiers()& Qt::ControlModifier
         && keyEvent->key() == Qt::Key_Return)
-        emit accepted();
+        Q_EMIT accepted();
     else if (keyEvent->key() == Qt::Key_Escape)
-        emit rejected();
+        Q_EMIT rejected();
     else
         QPlainTextEdit::keyPressEvent(keyEvent);
 }
@@ -133,7 +133,7 @@ int displayNotes(QTextBrowser* browser, const QVector< Note >& notes, int active
     if (!notes.isEmpty()) {
         t.insertHtml(i18nc("@info XLIFF notes representation", "<b>Notes:</b>") + BR);
         int i = 0;
-        foreach (const Note& note, notes) {
+        for (const Note& note : notes) {
             if (!note.from.isEmpty())
                 t.insertHtml(QStringLiteral("<i>") + note.from + QStringLiteral(":</i> "));
 
